!     -*- f90 -*-
!     This file is autogenerated with f2py (version:1.20.3)
!     It contains Fortran 90 wrappers to fortran functions.

      subroutine f2pywrap_fortranfit_f90_fit_blackscholesmerton_model (f&
     &90_fit_blackscholesmerton_modelf2pywrap, nbpts, ts, prices)
      use fortranfit, only : f90_fit_blackscholesmerton_model
      integer nbpts
      real ts(nbpts)
      real prices(nbpts)
      real f90_fit_blackscholesmerton_modelf2pywrap(2)
      f90_fit_blackscholesmerton_modelf2pywrap = f90_fit_blackscholesmer&
     &ton_model(nbpts, ts, prices)
      end subroutine f2pywrap_fortranfit_f90_fit_blackscholesmerton_mode&
     &l
      
      subroutine f2pyinitfortranfit(f2pysetupfunc)
      interface 
      subroutine f2pywrap_fortranfit_f90_fit_blackscholesmerton_model (f&
     &90_fit_blackscholesmerton_modelf2pywrap, f90_fit_blackscholesmerto&
     &n_model, nbpts, ts, prices)
      integer nbpts
      real ts(nbpts)
      real prices(nbpts)
      real f90_fit_blackscholesmerton_model(2)
      real f90_fit_blackscholesmerton_modelf2pywrap(2)
      end subroutine f2pywrap_fortranfit_f90_fit_blackscholesmerton_mode&
     &l
      end interface
      external f2pysetupfunc
      call f2pysetupfunc(f2pywrap_fortranfit_f90_fit_blackscholesmerton_&
     &model)
      end subroutine f2pyinitfortranfit


