!     -*- f90 -*-
!     This file is autogenerated with f2py (version:1.20.3)
!     It contains Fortran 90 wrappers to fortran functions.

      subroutine f2pywrap_fortranrisk_fortran_estimate_downside_risk (fo&
     &rtran_estimate_downside_riskf2pywrap, nbpts, ts, prices, target_re&
     &turn)
      use fortranrisk, only : fortran_estimate_downside_risk
      integer nbpts
      real target_return
      real ts(nbpts)
      real prices(nbpts)
      real fortran_estimate_downside_riskf2pywrap
      fortran_estimate_downside_riskf2pywrap = fortran_estimate_downside&
     &_risk(nbpts, ts, prices, target_return)
      end subroutine f2pywrap_fortranrisk_fortran_estimate_downside_risk
      subroutine f2pywrap_fortranrisk_fortran_estimate_upside_risk (fort&
     &ran_estimate_upside_riskf2pywrap, nbpts, ts, prices, target_return&
     &)
      use fortranrisk, only : fortran_estimate_upside_risk
      integer nbpts
      real target_return
      real ts(nbpts)
      real prices(nbpts)
      real fortran_estimate_upside_riskf2pywrap
      fortran_estimate_upside_riskf2pywrap = fortran_estimate_upside_ris&
     &k(nbpts, ts, prices, target_return)
      end subroutine f2pywrap_fortranrisk_fortran_estimate_upside_risk
      
      subroutine f2pyinitfortranrisk(f2pysetupfunc)
      interface 
      subroutine f2pywrap_fortranrisk_fortran_estimate_downside_risk (fo&
     &rtran_estimate_downside_riskf2pywrap, fortran_estimate_downside_ri&
     &sk, nbpts, ts, prices, target_return)
      real fortran_estimate_downside_risk
      integer nbpts
      real target_return
      real ts(nbpts)
      real prices(nbpts)
      real fortran_estimate_downside_riskf2pywrap
      end subroutine f2pywrap_fortranrisk_fortran_estimate_downside_risk&
     & 
      subroutine f2pywrap_fortranrisk_fortran_estimate_upside_risk (fort&
     &ran_estimate_upside_riskf2pywrap, fortran_estimate_upside_risk, nb&
     &pts, ts, prices, target_return)
      real fortran_estimate_upside_risk
      integer nbpts
      real target_return
      real ts(nbpts)
      real prices(nbpts)
      real fortran_estimate_upside_riskf2pywrap
      end subroutine f2pywrap_fortranrisk_fortran_estimate_upside_risk
      end interface
      external f2pysetupfunc
      call f2pysetupfunc(f2pywrap_fortranrisk_fortran_estimate_downside_&
     &risk,f2pywrap_fortranrisk_fortran_estimate_upside_risk)
      end subroutine f2pyinitfortranrisk


